AtCoder Carbon Command
======================

Tweet images of source code submitted to AtCoder.

Install
-------

::

   $ pip3 install accarbon

Usage
-----

::

   $ accarbon https://atcoder.jp/contests/abc170/submissions/14465204?lang=ja

Supported Language
------------------

We ensure that syntax highlighting is correct for submissions in the
following languages.

-  C (GCC 9.2.1)
-  C (Clang 10.0.0)
-  C++ (GCC 9.2.1)
-  C++ (Clang 10.0.0)
-  Java (OpenJDK 11.0.6)
-  Python (3.8.2)
-  Ruby (2.7.1)
-  C# (.NET Core 3.1.201)
-  PyPy3 (7.3.0)
-  Haskell (GHC 8.8.3)
-  Rust (1.42.0)

Tools for Development
---------------------

-  flake8
-  autopep8
-  pandoc

License
-------

This software is released under the MIT License, see LICENSE.
